@@ -342,7 +342,7 @@ fn spatial_match_helper(
             let mut found = false;
             let found_direction;
             let mut cur_direction = -1;
-            let adjacents = graph.get(&prev_char).cloned().unwrap_or_else(Vec::new);
+            let adjacents = graph.get(&prev_char).cloned().unwrap_or_default();
             // consider growing pattern by one character if j hasn't gone over the edge.
             if j < password_len {
                 let cur_char = password.chars().nth(j).unwrap();
@@ -773,7 +773,7 @@ fn map_ints_to_ymd(first: u16, second: u16, third: u16) -> Option<(i32, i8, i8)>
     // first look for a four digit year: yyyy + daymonth or daymonth + yyyy
     let possible_year_splits = &[(third, first, second), (first, second, third)];
     for &(year, second, third) in possible_year_splits {
-        if DATE_MIN_YEAR <= year && year <= DATE_MAX_YEAR {
+        if (DATE_MIN_YEAR..=DATE_MAX_YEAR).contains(&year) {
             let dm = map_ints_to_md(second, third);
             if let Some(dm) = dm {
                 return Some((i32::from(year), dm.0, dm.1));
@@ -1442,8 +1442,10 @@ mod tests {
 
     #[test]
     fn test_date_matches_year_closest_to_reference_year() {
-        use chrono::{Datelike, Local};
-        let password = format!("1115{}", Local::today().year() % 100);
+        use time::OffsetDateTime;
+
+        let now = OffsetDateTime::now_utc();
+        let password = format!("1115{}", now.year() % 100);
         let matches = (matching::DateMatch {}).get_matches(&password, &HashMap::new());
         let m = matches.iter().find(|m| m.token == password).unwrap();
         assert_eq!(m.i, 0);
@@ -1453,7 +1455,7 @@ mod tests {
         } else {
             panic!("Wrong match pattern")
         };
-        assert_eq!(p.year, Local::today().year());
+        assert_eq!(p.year, now.year());
         assert_eq!(p.month, 11);
         assert_eq!(p.day, 15);
         assert_eq!(p.separator, "".to_string());
